@@ -1,6 +1,6 @@
 import logging
 
-from crownstone_core.Exceptions import CrownstoneError
+from crownstone_core.Exceptions import CrownstoneException
 from crownstone_core.util.BufferReader import BufferReader
 from crownstone_core.util.Conversion import Conversion
 
@@ -15,7 +15,7 @@ class UartMessagePacket:
 	xB data
 	"""
 
-	def __init__(self, opCode: UartTxType = UartTxType.UNKNOWN, payload: list = None):
+	def __init__(self, opCode: UartTxType = UartTxType.UNKNOWN, payload: list or bytearray = None):
 		"""
 		:param opCode:       uint16 data type.
 		:param payload:      List of uint8, according to data type
@@ -37,11 +37,11 @@ class UartMessagePacket:
 			self.opCode = reader.getUInt16()
 			self.payload = reader.getRemainingBytes()
 			return True
-		except CrownstoneError as e:
+		except CrownstoneException as e:
 			_LOGGER.warning(F"Parse error: {e}")
 			return False
 
-	def getPacket(self):
+	def serialize(self):
 		# Header: 1B device ID, 2B opcode
 
 		# construct the basePacket, which is used for CRC calculation
